#include "StdAfx.h"

TariffCalculator::TariffCalculator(void)
{
}

TariffCalculator::~TariffCalculator(void)
{
}

/**
*
*
*/
void TariffCalculator::parse(std::string filename) {
	std::ifstream tariffData(filename.c_str());
	std::string currentTariff;

	if (!tariffData) {
		MessageBox(0, "Cannot open tariffs file!", "Error", MB_ICONERROR);
		exit (-1);
	}

	/// Parse the tariffs file, using two very useful Boost features:
	/// lexical casts and a tokenizer implementation.
	while (getline(tariffData, currentTariff)) {
		typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
		boost::char_separator<char> sep("|");
		tokenizer tokens(currentTariff, sep);

		Tariff* tariff = new Tariff();
		tokenizer::iterator tok_iter = tokens.begin();
		tariff->setCountry(*tok_iter++);
		tariff->setDayTariff(boost::lexical_cast<float>(*tok_iter++));
		tariff->setEveningTariff(boost::lexical_cast<float>(*tok_iter++));
		tariff->setWeekendTariff(boost::lexical_cast<float>(*tok_iter));

		tariffs[tariff->getCountry()] = tariff;
	}
}

/**
*
*/
float TariffCalculator::getCost(CallInfo* callInfo) {
	float cost = 5.5f;
	std::string* location = callInfo->callerCountry;
	long durationSeconds = (callInfo->duration);
	long durationMinutes = (callInfo->duration/60L);
	bool isDomestic = false;
	Tariff* tariff;

	// Duration in seconds must be rounded up to the nearest minute
	// A minimum tariff of 5.5p applies to all calls less than 1 minute
	if (durationSeconds < 60) {
		return cost;
	}

	//durationMinutes = std::ceil(durationMinutes);

	if (location->empty() || (location->compare("") == 0)) 
		isDomestic = true;

	// Attempt to retrieve a tariff record for the user's location
	TariffMap::const_iterator it = tariffs.find(*location);
	if (it == tariffs.end()) 
		isDomestic = true;
	else 
		tariff = it->second;

	if (isDomestic) {
		if(callInfo->tariffType == TariffType::EVENING 
			|| callInfo->tariffType == TariffType::WEEKEND) {

				/// UK prices are charged via the following system:
				/// 1. Evenings and weekends are 5.5p for the first hour
				/// and 3p per minute thereafter
				/// 2. Daytime calls are a flat 3p per minute
				if (durationMinutes > 60) {
					cost = 5.5f;
					durationMinutes -= 60;
					cost += (durationMinutes * 3.0f);
				}
		}
		else {	// Daytime tariff
			cost = (durationMinutes * 3.0f);
		}
	}
	else {		// International calls
		if (callInfo->tariffType == TariffType::DAY)
			cost = (tariff->getDayTariff() * durationMinutes);
		else if (callInfo->tariffType == TariffType::EVENING) 
			cost = (tariff->getEveningTariff() * durationMinutes);
		else if (callInfo->tariffType == TariffType::WEEKEND)
			cost = (tariff->getWeekendTariff() * durationMinutes);
	}

	return cost;
}


TariffMap& TariffCalculator::getTariffs(void) {
	return tariffs;
}
